#
# spec file for package skopeo
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# nodebuginfo


# Don't enable ostree by default, as libostree is only available in tumbleweed.
%bcond_with ostree

# Remove stripping of Go binaries.
%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           skopeo
Version:        0.1.23
Release:        lp150.3.3
Summary:        Container image repository tool
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/projectatomic/skopeo
Source:         %{name}-%{version}.tar.xz
BuildRequires:  golang(API) >= 1.11                                             
# go1.11.3 contains sec. fixes bsc#1118897(CVE-2018-16873) bsc#1118897(CVE-2018-16873) bsc#1118899(CVE-2018-16875)
BuildRequires:  go >= 1.11.3
BuildRequires:  go-go-md2man
BuildRequires:  libgpgme-devel
# Required for containers/storage integration.
BuildRequires:  device-mapper-devel >= 1.2.68
BuildRequires:  glib2-devel
BuildRequires:  libbtrfs-devel >= 3.8
%if 0%{with ostree}
BuildRequires:  libostree-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       libcontainers-common

%description
skopeo is a command line utility for various operations on container images and
image repositories. skopeo is able to inspect a repository on a Docker registry
and fetch images layers. skopeo can copy container images between various
storage mechanisms.

%prep
%setup -q

%build
mkdir -p .gopath/src/github.com/projectatomic
ln -s $PWD .gopath/src/github.com/projectatomic/skopeo
export GOPATH=$PWD/.gopath

export BUILDTAGS="exclude_graphdriver_aufs"
%if 0%{?suse_version} <= 1320
	BUILDTAGS+=" libdm_no_deferred_remove"
%endif
%if ! 0%{with ostree}
	BUILDTAGS+=" containers_image_ostree_stub"
%endif

# Build.
go build -ldflags "-X main.gitCommit=" -gcflags "" -tags "$BUILDTAGS" -o skopeo github.com/projectatomic/skopeo/cmd/skopeo
make docs

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
make INSTALLDIR="%{buildroot}/%{_bindir}" install-binary

# Install the docs.
make MANINSTALLDIR="%{buildroot}/%{_mandir}" install-docs

%files
%defattr(-,root,root)
%doc LICENSE README.md
%{_bindir}/%{name}
%{_mandir}/man1/skopeo.1*

%changelog
* Tue Dec 18 2018 jmassaguerpla@suse.com
- Update go requirements to >= go1.11.3 to fix
  * bsc#1118897 CVE-2018-16873
    go#29230 cmd/go: remote command execution during "go get -u"
  * bsc#1118898 CVE-2018-16874
    go#29231 cmd/go: directory traversal in "go get" via curly braces in import paths
  * bsc#1118899 CVE-2018-16875
    go#29233 crypto/x509: CPU denial of service
* Fri Feb  9 2018 vrothberg@suse.com
- Add requirement on libcontainers-common, which now provides the
  /etc/containers/policy.json config.
* Sat Jul 22 2017 asarai@suse.com
- Update to skopeo v0.1.23. This supports OCI v1, as well as a variety of new
  transports such as docker-archive and ostree.
- Disable ostree builds by default with %%bcond_with, as only Tumbleweed has
  libostree and we need skopeo for KIWI.
* Fri Apr 21 2017 asarai@suse.com
- Update to skopeo 0.1.19, which supports 1.0.0-rc4 of the image-spec as well
  as all of our patches have been merged upstream.
  - 0001-docker-split-tarfile-code-from-docker-daemon-code.patch
  - 0002-docker-add-docker-archive-transport.patch
  - 0003-squashme-docker-tarfile-make-tagging-work-properly.patch
  - 0004-squashme-docker-archive-handle-mtrmac-s-comments.patch
  - 0005-squashme-docker-archive-correctly-handle-tagging.patch
  - 0006-copy-move-compression-to-separate-pkg.patch
  - 0007-docker-daemon-decompress-blobs-transparently-in-GetB.patch
  - oci-remove-MIME-type-autodetection.patch
* Thu Apr 20 2017 jengelh@inai.de
- Drop %%__-type macro indirections
* Tue Apr 11 2017 jmassaguerpla@suse.com
- remove the go_arches macro because we are using go1.7 which
  is available in all archs
* Wed Feb 15 2017 asarai@suse.com
- Add further patches to handle OCI <-> Docker translation properly. This is
  necessary for KIWI integration. https://github.com/containers/image/pull/237
  + oci-remove-MIME-type-autodetection.patch
* Tue Feb  7 2017 asarai@suse.com
- Add buildtags to handle the Docker-like buildtags such as
  libdm_no_deferred_remove and exclude_graphdriver_aufs.
* Tue Feb  7 2017 asarai@suse.com
- Add patches for docker-archive transport.
  + 0001-docker-split-tarfile-code-from-docker-daemon-code.patch
  + 0002-docker-add-docker-archive-transport.patch
  + 0003-squashme-docker-tarfile-make-tagging-work-properly.patch
  + 0004-squashme-docker-archive-handle-mtrmac-s-comments.patch
  + 0005-squashme-docker-archive-correctly-handle-tagging.patch
  + 0006-copy-move-compression-to-separate-pkg.patch
  + 0007-docker-daemon-decompress-blobs-transparently-in-GetB.patch
* Tue Feb  7 2017 asarai@suse.com
- Bump to skopeo v0.1.18. Many updates to containers/image, and fixes to the
  Docker v2s2 schema conversion.
* Tue Dec 13 2016 asarai@suse.com
- Bump to skopeo v0.1.17. This version includes many, many fixes to OCI image
  handling as well as adding features such as the docker-daemon: transport.
  There are also several UX fixes to how passwords are managed.
* Thu Dec  8 2016 asarai@suse.com
- Bump to v0.1.16+r54 (a865c07818ed914e2602205be6e9d67debc1d660). This is
  necessary so that we don't need to do major backporting of containers/image.
  skopeo intends to bump themselves to v0.1.17 in the coming week so this is
  just a temporary measure.
- Removed patches no longer needed.
  - oci-fix-mediatypes.patch
* Fri Nov 11 2016 asarai@suse.com
- Backport OCI mediatype fixes. https://github.com/projectatomic/skopeo/pull/221
  + oci-fix-mediatypes.patch
* Fri Nov 11 2016 asarai@suse.com
- Initial import of skopeo v0.1.16.
